# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: featurestore/core/Statistics.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from featurestore.core import CoreService_pb2 as featurestore_dot_core_dot_CoreService__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='featurestore/core/Statistics.proto',
  package='featurestore.core',
  syntax='proto3',
  serialized_options=b'\n\030ai.h2o.featurestore.coreB\017StatisticsProto',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\"featurestore/core/Statistics.proto\x12\x11\x66\x65\x61turestore.core\x1a#featurestore/core/CoreService.proto\"\x83\x01\n\x10IngestStatistics\x12\x0b\n\x03min\x18\x01 \x01(\x01\x12\x0b\n\x03max\x18\x02 \x01(\x01\x12\x10\n\x08num_rows\x18\x03 \x01(\x04\x12\x12\n\nnull_count\x18\x04 \x01(\x04\x12\x11\n\tnan_count\x18\x05 \x01(\x04\x12\x0c\n\x04mean\x18\x06 \x01(\x01\x12\x0e\n\x06stddev\x18\x07 \x01(\x01\"\xeb\x01\n\x0e\x46ullStatistics\x12R\n\x0fnumerical_stats\x18\x01 \x01(\x0b\x32\x39.featurestore.core.FullStatistics.FullNumericalStatistics\x12J\n\x11\x63\x61tegorical_stats\x18\x02 \x01(\x0b\x32/.featurestore.core.CategoricalFeatureStatistics\x1a\x39\n\x17\x46ullNumericalStatistics\x12\x0e\n\x06median\x18\x01 \x01(\x01\x12\x0e\n\x06unique\x18\x02 \x01(\x04\x42+\n\x18\x61i.h2o.featurestore.coreB\x0fStatisticsProtob\x06proto3'
  ,
  dependencies=[featurestore_dot_core_dot_CoreService__pb2.DESCRIPTOR,])




_INGESTSTATISTICS = _descriptor.Descriptor(
  name='IngestStatistics',
  full_name='featurestore.core.IngestStatistics',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='min', full_name='featurestore.core.IngestStatistics.min', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max', full_name='featurestore.core.IngestStatistics.max', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='num_rows', full_name='featurestore.core.IngestStatistics.num_rows', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='null_count', full_name='featurestore.core.IngestStatistics.null_count', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nan_count', full_name='featurestore.core.IngestStatistics.nan_count', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mean', full_name='featurestore.core.IngestStatistics.mean', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stddev', full_name='featurestore.core.IngestStatistics.stddev', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=95,
  serialized_end=226,
)


_FULLSTATISTICS_FULLNUMERICALSTATISTICS = _descriptor.Descriptor(
  name='FullNumericalStatistics',
  full_name='featurestore.core.FullStatistics.FullNumericalStatistics',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='median', full_name='featurestore.core.FullStatistics.FullNumericalStatistics.median', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unique', full_name='featurestore.core.FullStatistics.FullNumericalStatistics.unique', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=407,
  serialized_end=464,
)

_FULLSTATISTICS = _descriptor.Descriptor(
  name='FullStatistics',
  full_name='featurestore.core.FullStatistics',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='numerical_stats', full_name='featurestore.core.FullStatistics.numerical_stats', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='categorical_stats', full_name='featurestore.core.FullStatistics.categorical_stats', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_FULLSTATISTICS_FULLNUMERICALSTATISTICS, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=229,
  serialized_end=464,
)

_FULLSTATISTICS_FULLNUMERICALSTATISTICS.containing_type = _FULLSTATISTICS
_FULLSTATISTICS.fields_by_name['numerical_stats'].message_type = _FULLSTATISTICS_FULLNUMERICALSTATISTICS
_FULLSTATISTICS.fields_by_name['categorical_stats'].message_type = featurestore_dot_core_dot_CoreService__pb2._CATEGORICALFEATURESTATISTICS
DESCRIPTOR.message_types_by_name['IngestStatistics'] = _INGESTSTATISTICS
DESCRIPTOR.message_types_by_name['FullStatistics'] = _FULLSTATISTICS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

IngestStatistics = _reflection.GeneratedProtocolMessageType('IngestStatistics', (_message.Message,), {
  'DESCRIPTOR' : _INGESTSTATISTICS,
  '__module__' : 'featurestore.core.Statistics_pb2'
  # @@protoc_insertion_point(class_scope:featurestore.core.IngestStatistics)
  })
_sym_db.RegisterMessage(IngestStatistics)

FullStatistics = _reflection.GeneratedProtocolMessageType('FullStatistics', (_message.Message,), {

  'FullNumericalStatistics' : _reflection.GeneratedProtocolMessageType('FullNumericalStatistics', (_message.Message,), {
    'DESCRIPTOR' : _FULLSTATISTICS_FULLNUMERICALSTATISTICS,
    '__module__' : 'featurestore.core.Statistics_pb2'
    # @@protoc_insertion_point(class_scope:featurestore.core.FullStatistics.FullNumericalStatistics)
    })
  ,
  'DESCRIPTOR' : _FULLSTATISTICS,
  '__module__' : 'featurestore.core.Statistics_pb2'
  # @@protoc_insertion_point(class_scope:featurestore.core.FullStatistics)
  })
_sym_db.RegisterMessage(FullStatistics)
_sym_db.RegisterMessage(FullStatistics.FullNumericalStatistics)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
